summaryrefslogtreecommitdiffstats
path: root/kdevdesigner/designer/projectsettingsimpl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdevdesigner/designer/projectsettingsimpl.cpp')
-rw-r--r--kdevdesigner/designer/projectsettingsimpl.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kdevdesigner/designer/projectsettingsimpl.cpp b/kdevdesigner/designer/projectsettingsimpl.cpp
index 8d213a0a..b616930d 100644
--- a/kdevdesigner/designer/projectsettingsimpl.cpp
+++ b/kdevdesigner/designer/projectsettingsimpl.cpp
@@ -1,15 +1,15 @@
/**********************************************************************
** Copyright (C) 2000-2001 Trolltech AS. All rights reserved.
**
-** This file is part of Qt Designer.
+** This file is part of TQt Designer.
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
-** Licensees holding valid Qt Enterprise Edition or Qt Professional Edition
-** licenses may use this file in accordance with the Qt Commercial License
+** Licensees holding valid TQt Enterprise Edition or TQt Professional Edition
+** licenses may use this file in accordance with the TQt Commercial License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
@@ -17,7 +17,7 @@
**
** See http://www.trolltech.com/gpl/ for GPL licensing information.
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-** information about Qt Commercial License Agreements.
+** information about TQt Commercial License Agreements.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
@@ -48,14 +48,14 @@
#include <tqlabel.h>
/*
* Constructs a ProjectSettings which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-ProjectSettings::ProjectSettings( Project *pro, TQWidget* parent, const char* name, bool modal, WFlags fl )
- : ProjectSettingsBase( parent, name, modal, fl ), project( pro )
+ProjectSettings::ProjectSettings( Project *pro, TQWidget* tqparent, const char* name, bool modal, WFlags fl )
+ : ProjectSettingsBase( tqparent, name, modal, fl ), project( pro )
{
connect( buttonHelp, TQT_SIGNAL( clicked() ), MainWindow::self, TQT_SLOT( showDialogHelp() ) );
@@ -48,14 +48,14 @@
#include <tqlabel.h>
/*
- * Constructs a ProjectSettings which is a child of 'parent', with the
+ * Constructs a ProjectSettings which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*